@@ -1150,7 +1150,7 @@ void AgendaView::placeDecorations(DecorationList &decoList, const QDate &date, Q
             decoHBox->setMinimumWidth(1);
 
             foreach (CalendarDecoration::Element *it, elements) {
-                DecorationLabel *label = new DecorationLabel(it);
+                DecorationLabel *label = new DecorationLabel(it, decoHBox);
                 label->setAlignment(Qt::AlignBottom);
                 label->setMinimumWidth(1);
                 layout->addWidget(label);
@@ -1293,6 +1293,8 @@ void AgendaView::createDayLabels(bool force)
     // Update the labels now and after a single event loop run. Now to avoid flicker, and
     // delayed so that the delayed layouting size is taken into account.
     updateDayLabelSizes();
+    qDeleteAll(topDecos);
+    qDeleteAll(botDecos);
 }
 
 void AgendaView::updateDayLabelSizes()
